#ifndef USER_H_
#define USER_H_


#include "DSP28x_Project.h"								// Headers for C28346
#include "extern_user.h"								// Corresponding pre-compiled header


/**
 * Pre-computed general constants
 */
#define PI (3.141592654)
#define TWOPI (2*PI)


/**
 * Time-related definitions
 */
#define SWITCHING_FREQUENCY (20e3)						// Apparent switching frequency
#define SAMPLING_PERIOD (1/SWITCHING_FREQUENCY)			// Sampling and control period (dsp)
#define SAMPLING_PERIOD_US (1/SWITCHING_FREQUENCY*1e6)	// Same thing in microseconds...
#define SIGNAL_PERIOD (20e-3)							// 50Hz -> 20ms
#define FPGA_CLK_PERIOD (33.33e-9)						// 30Mhz -> 33.3ns


/**
 * Application-specific parameters
 */
#define LGRID (0.5e-3)									// Line inductance (H)
#define RGRID (0.8)										// Line resistance (Ohms)
#define OMEGA (TWOPI/SIGNAL_PERIOD)						// Line pulsation
#define IG_NOMINAL (20)									// Nominal line current

/**
 * Modes of operation for the user-level application
 * These definitions apply to the user state machine
 */
typedef enum {
	STANDBY =0,
	CLOSEDLOOP =1,
	PASSIVELOAD = 2
} USER_STATE;


/**
 * First user-level interrupt service routine.
 * Remember that it has the highest level of priority when mapped to Ext1, intermediate when
 * mapped to Ext2 and lowest when mapped to the CPU Timer.
 * @param	void	no parameters
 * @return 			SAFE or UNSAFE depending on whether the user wants to trigger the blocking of the application or not
 */
USER_SAFE UserInterrupt1(void);


/**
 * First user-level interrupt service routine.
 * Remember that it has the highest level of priority when mapped to Ext1, intermediate when
 * mapped to Ext2 and lowest when mapped to the CPU Timer.
 * @param	void	no parameters
 * @return 			SAFE or UNSAFE depending on whether the user wants to trigger the blocking of the application or not
 */
USER_SAFE UserInterrupt2(void);


/**
 * Routine to change the operation mode of the application
 * It is highly recommended to personalize this routine to comply with application-related needs
 * @param 	opmode	the new mode of operation
 * @return 			void
 */
void SetOpMode(USER_STATE opmode);


/**
 * The following prototypes are already defined in the pre-compiled library (extern_user.h)
 * They do not need to be specified here
 */
// USER_SAFE UserInit(void)
// void UserError(int code);


#endif /* USER_H_ */
